import network
import espnow
import machine
import robot
import uasyncio
import utime

def receiver():
    async def receive_messages(esp, command_queue):
        """Asynchroniczne odbieranie wiadomości."""
        while True:
            _, msg = esp.recv()
            if msg:
                print(f"Odebrano wiadomość: {msg}")
                command_queue.append(msg)  # Dodaj wiadomość do listy
            await uasyncio.sleep(0.01)  # Krótka przerwa dla innych zadań

    async def process_commands(command_queue):
        """Asynchroniczne przetwarzanie kolejki komend."""
        while True:
            if command_queue:  # Sprawdź, czy lista nie jest pusta
                command = command_queue.pop(0)  # Pobierz pierwszy element z kolejki
                print(f"Przetwarzanie polecenia: {command}")
                
                if command == b'forward':
                    print("Jedzie do przodu")
                    robot.goForward(1, 700)
                elif command == b'backward':
                    print("Jedzie do tyłu")
                    robot.goBack(1, 700)
                elif command == b'left':
                    print("Skręca w lewo")
                    robot.turnLeft(0.43, 700)
                elif command == b'right':
                    print("Skręca w prawo")
                    robot.turnRight(0.43, 700)
                else:
                    print(f"Nieznane polecenie: {command}")
                
                robot.stopEngine()  # Zatrzymanie po wykonaniu ruchu
            await uasyncio.sleep(0.01)  # Przerwa, aby inne zadania mogły działać

    async def main():
        # Konfiguracja ESP-NOW
        sta = network.WLAN(network.STA_IF)
        sta.active(True)
        sta.disconnect()  # Dla ESP8266
        
        esp = espnow.ESPNow()
        esp.active(True)

        # Prosta lista jako kolejka komend
        command_queue = []

        # Uruchomienie zadań
        await uasyncio.gather(
            receive_messages(esp, command_queue),
            process_commands(command_queue)
        )

    # Uruchomienie programu głównego
    uasyncio.run(main())
