import network
from machine import Pin
import espnow
import utime

def sender():
    # A WLAN interface must be active to send()/recv()
    sta = network.WLAN(network.STA_IF)  # Or network.AP_IF
    sta.active(True)
    sta.disconnect()  # For ESP8266

    # Initialize ESP-NOW
    esp = espnow.ESPNow()
    esp.active(True)

    # Define the MAC address of the receiving ESP32
    peer = b'$o(\xaf\xb94'  #ESP32 MAC address
    esp.add_peer(peer)

    # Map pins to buttons
    buttons = {
        "forward": Pin(13, Pin.IN, Pin.PULL_UP), #13
        "backward": Pin(12, Pin.IN, Pin.PULL_UP), #12
        "left": Pin(14, Pin.IN, Pin.PULL_UP), #14
        "right": Pin(2, Pin.IN, Pin.PULL_UP), #2
    }

    # Initialize variables for debouncing
    last_button_states = {key: 1 for key in buttons}  # Assume buttons are not pressed initially
    debounce_delay = 50  # Adjust this value to your needs (milliseconds)

    while True:
        for action, pin in buttons.items():
            # Read the current state of the button
            current_state = pin.value()

            # Check if the button state has changed
            if current_state != last_button_states[action]:
                # Wait for a short time to debounce the button
                utime.sleep_ms(debounce_delay)

                # Read the button state again to make sure it's stable
                current_state = pin.value()

                # If the button state is still different, it's a valid press
                if current_state != last_button_states[action]:
                    if current_state == 0:  # Button pressed
                        print(f"Wysyłanie komendy: {action}")
                        esp.send(peer, action)
            
            # Update the last button state
            last_button_states[action] = current_state
